export declare class UUID {
    private str;
    /**
     * Creates a UUID string.
     * @returns {string} A UUID string.
     */
    private static createUUID();
    /**
     * Check if the given test string is a valid uuid string.
     * https://stackoverflow.com/questions/7905929/how-to-test-valid-uuid-UUID/13653180#13653180
     * @param {string} uuidTestString
     * @returns {boolean} True if it is a valid uuid string, otherwise false.
     */
    private static isValidUUID(uuidTestString);
    /**
     * Get the uuid string, if the passed string is a valid uuid string.
     * @param {string} str
     * @returns {string} The uuid string, if it is a valid uuid, otherwise null.
     */
    private static getValidUUID(str);
    /**
     * Get a dash free UUID.
     * @param {UUID} uuid
     * @returns {String} A dash free UUID.
     */
    static getDashFreeUUID(uuid: UUID): string;
    static getDashContainedUUID(dashFreeUuid: string): UUID;
    /**
     * Constructs a new UUID from the given parameter, if it is a valid UUID string.
     * If no parameter is passed, a UUID will be generated.
     * @param {string} [str]
     * @throws {UUIDError}
     */
    constructor(str?: string);
    /**
     * Checks if the given UUID string or class is equal to this UUID.
     * @param {string|UUID} uuid
     * @returns {boolean}
     */
    equals(uuid: string | UUID): boolean;
    getDashFreeUUID(): string;
    /**
     * Get the UUID in string representation.
     * @returns {string} UUID as string.
     */
    toString(): string;
}
